From f43b3741d56305f47e639d447fc15783227f8654 Mon Sep 17 00:00:00 2001
From: Alvaro Herrera <alvherre@alvh.no-ip.org>
Date: Mon, 23 Dec 2019 16:26:52 -0300
Subject: [PATCH 2/2] Fix line continuation

---
 contrib/dblink/dblink.c               | 15 ++++--------
 contrib/tablefunc/tablefunc.c         | 35 +++++++++------------------
 src/backend/access/transam/xlog.c     |  4 +--
 src/backend/executor/execExprInterp.c |  4 +--
 4 files changed, 20 insertions(+), 38 deletions(-)

diff --git a/contrib/dblink/dblink.c b/contrib/dblink/dblink.c
index 7e225589a9..a28b080059 100644
--- a/contrib/dblink/dblink.c
+++ b/contrib/dblink/dblink.c
@@ -1639,8 +1639,7 @@ dblink_build_sql_insert(PG_FUNCTION_ARGS)
 	if (src_nitems != pknumatts)
 		ereport(ERROR,
 				(errcode(ERRCODE_ARRAY_SUBSCRIPT_ERROR),
-				 errmsg("source key array length must match number of key " \
-						"attributes")));
+				 errmsg("source key array length must match number of key attributes")));
 
 	/*
 	 * Target array is made up of key values that will be used to build the
@@ -1654,8 +1653,7 @@ dblink_build_sql_insert(PG_FUNCTION_ARGS)
 	if (tgt_nitems != pknumatts)
 		ereport(ERROR,
 				(errcode(ERRCODE_ARRAY_SUBSCRIPT_ERROR),
-				 errmsg("target key array length must match number of key " \
-						"attributes")));
+				 errmsg("target key array length must match number of key attributes")));
 
 	/*
 	 * Prep work is finally done. Go get the SQL string.
@@ -1727,8 +1725,7 @@ dblink_build_sql_delete(PG_FUNCTION_ARGS)
 	if (tgt_nitems != pknumatts)
 		ereport(ERROR,
 				(errcode(ERRCODE_ARRAY_SUBSCRIPT_ERROR),
-				 errmsg("target key array length must match number of key " \
-						"attributes")));
+				 errmsg("target key array length must match number of key attributes")));
 
 	/*
 	 * Prep work is finally done. Go get the SQL string.
@@ -1807,8 +1804,7 @@ dblink_build_sql_update(PG_FUNCTION_ARGS)
 	if (src_nitems != pknumatts)
 		ereport(ERROR,
 				(errcode(ERRCODE_ARRAY_SUBSCRIPT_ERROR),
-				 errmsg("source key array length must match number of key " \
-						"attributes")));
+				 errmsg("source key array length must match number of key attributes")));
 
 	/*
 	 * Target array is made up of key values that will be used to build the
@@ -1822,8 +1818,7 @@ dblink_build_sql_update(PG_FUNCTION_ARGS)
 	if (tgt_nitems != pknumatts)
 		ereport(ERROR,
 				(errcode(ERRCODE_ARRAY_SUBSCRIPT_ERROR),
-				 errmsg("target key array length must match number of key " \
-						"attributes")));
+				 errmsg("target key array length must match number of key attributes")));
 
 	/*
 	 * Prep work is finally done. Go get the SQL string.
diff --git a/contrib/tablefunc/tablefunc.c b/contrib/tablefunc/tablefunc.c
index 30d94f5d90..db9885be1b 100644
--- a/contrib/tablefunc/tablefunc.c
+++ b/contrib/tablefunc/tablefunc.c
@@ -443,8 +443,7 @@ crosstab(PG_FUNCTION_ARGS)
 	if (!compatCrosstabTupleDescs(tupdesc, spi_tupdesc))
 		ereport(ERROR,
 				(errcode(ERRCODE_SYNTAX_ERROR),
-				 errmsg("return and sql tuple descriptions are " \
-						"incompatible")));
+				 errmsg("return and sql tuple descriptions are incompatible")));
 
 	/*
 	 * switch to long-lived memory context
@@ -667,8 +666,7 @@ crosstab_hash(PG_FUNCTION_ARGS)
 	if (tupdesc->natts < 2)
 		ereport(ERROR,
 				(errcode(ERRCODE_SYNTAX_ERROR),
-				 errmsg("query-specified return tuple and " \
-						"crosstab function are not compatible")));
+				 errmsg("query-specified return tuple and crosstab function are not compatible")));
 
 	/* load up the categories hash table */
 	crosstab_hash = load_categories_hash(cats_sql, per_query_ctx);
@@ -746,8 +744,7 @@ load_categories_hash(char *cats_sql, MemoryContext per_query_ctx)
 		if (spi_tupdesc->natts != 1)
 			ereport(ERROR,
 					(errcode(ERRCODE_SYNTAX_ERROR),
-					 errmsg("provided \"categories\" SQL must " \
-							"return 1 column of at least one row")));
+					 errmsg("provided \"categories\" SQL must return 1 column of at least one row")));
 
 		for (i = 0; i < proc; i++)
 		{
@@ -829,8 +826,7 @@ get_crosstab_tuplestore(char *sql,
 			/* no qualifying category tuples */
 			ereport(ERROR,
 					(errcode(ERRCODE_SYNTAX_ERROR),
-					 errmsg("provided \"categories\" SQL must " \
-							"return 1 column of at least one row")));
+					 errmsg("provided \"categories\" SQL must return 1 column of at least one row")));
 		}
 
 		/*
@@ -850,8 +846,7 @@ get_crosstab_tuplestore(char *sql,
 			ereport(ERROR,
 					(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
 					 errmsg("invalid source data SQL statement"),
-					 errdetail("The provided SQL must return 3 " \
-							   " columns; rowid, category, and values.")));
+					 errdetail("The provided SQL must return 3 columns; rowid, category, and values.")));
 
 		result_ncols = (ncols - 2) + num_categories;
 
@@ -860,9 +855,8 @@ get_crosstab_tuplestore(char *sql,
 			ereport(ERROR,
 					(errcode(ERRCODE_SYNTAX_ERROR),
 					 errmsg("invalid return type"),
-					 errdetail("Query-specified return " \
-							   "tuple has %d columns but crosstab " \
-							   "returns %d.", tupdesc->natts, result_ncols)));
+					 errdetail("Query-specified return tuple has %d columns but crosstab returns %d.",
+							   tupdesc->natts, result_ncols)));
 
 		/* allocate space and make sure it's clear */
 		values = (char **) palloc0(result_ncols * sizeof(char *));
@@ -1427,8 +1421,7 @@ validateConnectbyTupleDesc(TupleDesc td, bool show_branch, bool show_serial)
 			ereport(ERROR,
 					(errcode(ERRCODE_DATATYPE_MISMATCH),
 					 errmsg("invalid return type"),
-					 errdetail("Query-specified return tuple has " \
-							   "wrong number of columns.")));
+					 errdetail("Query-specified return tuple has wrong number of columns.")));
 	}
 	else
 	{
@@ -1436,8 +1429,7 @@ validateConnectbyTupleDesc(TupleDesc td, bool show_branch, bool show_serial)
 			ereport(ERROR,
 					(errcode(ERRCODE_DATATYPE_MISMATCH),
 					 errmsg("invalid return type"),
-					 errdetail("Query-specified return tuple has " \
-							   "wrong number of columns.")));
+					 errdetail("Query-specified return tuple has wrong number of columns.")));
 	}
 
 	/* check that the types of the first two columns match */
@@ -1517,8 +1509,7 @@ compatConnectbyTupleDescs(TupleDesc ret_tupdesc, TupleDesc sql_tupdesc)
 		ereport(ERROR,
 				(errcode(ERRCODE_DATATYPE_MISMATCH),
 				 errmsg("invalid return type"),
-				 errdetail("SQL key field type %s does " \
-						   "not match return key field type %s.",
+				 errdetail("SQL key field type %s does not match return key field type %s.",
 						   format_type_with_typemod(ret_atttypid, ret_atttypmod),
 						   format_type_with_typemod(sql_atttypid, sql_atttypmod))));
 
@@ -1531,8 +1522,7 @@ compatConnectbyTupleDescs(TupleDesc ret_tupdesc, TupleDesc sql_tupdesc)
 		ereport(ERROR,
 				(errcode(ERRCODE_DATATYPE_MISMATCH),
 				 errmsg("invalid return type"),
-				 errdetail("SQL parent key field type %s does " \
-						   "not match return parent key field type %s.",
+				 errdetail("SQL parent key field type %s does not match return parent key field type %s.",
 						   format_type_with_typemod(ret_atttypid, ret_atttypmod),
 						   format_type_with_typemod(sql_atttypid, sql_atttypmod))));
 
@@ -1562,8 +1552,7 @@ compatCrosstabTupleDescs(TupleDesc ret_tupdesc, TupleDesc sql_tupdesc)
 		ereport(ERROR,
 				(errcode(ERRCODE_DATATYPE_MISMATCH),
 				 errmsg("invalid return type"),
-				 errdetail("SQL rowid datatype does not match " \
-						   "return rowid datatype.")));
+				 errdetail("SQL rowid datatype does not match return rowid datatype.")));
 
 	/*
 	 * - attribute [1] of the sql tuple is the category; no need to check it -
diff --git a/src/backend/access/transam/xlog.c b/src/backend/access/transam/xlog.c
index edee0c0f22..5658971cb3 100644
--- a/src/backend/access/transam/xlog.c
+++ b/src/backend/access/transam/xlog.c
@@ -6135,9 +6135,7 @@ do { \
 	if ((currValue) < (minValue)) \
 		ereport(ERROR, \
 				(errcode(ERRCODE_INVALID_PARAMETER_VALUE), \
-				 errmsg("hot standby is not possible because " \
-						"%s = %d is a lower setting than on the master server " \
-						"(its value was %d)", \
+				 errmsg("hot standby is not possible because %s = %d is a lower setting than on the master server (its value was %d)", \
 						param_name, \
 						currValue, \
 						minValue))); \
diff --git a/src/backend/executor/execExprInterp.c b/src/backend/executor/execExprInterp.c
index dbed597816..034970648f 100644
--- a/src/backend/executor/execExprInterp.c
+++ b/src/backend/executor/execExprInterp.c
@@ -2739,8 +2739,8 @@ ExecEvalArrayExpr(ExprState *state, ExprEvalStep *op)
 				if (ndims <= 0 || ndims > MAXDIM)
 					ereport(ERROR,
 							(errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
-							 errmsg("number of array dimensions (%d) exceeds " \
-									"the maximum allowed (%d)", ndims, MAXDIM)));
+							 errmsg("number of array dimensions (%d) exceeds the maximum allowed (%d)",
+									ndims, MAXDIM)));
 
 				elem_dims = (int *) palloc(elem_ndims * sizeof(int));
 				memcpy(elem_dims, ARR_DIMS(array), elem_ndims * sizeof(int));
-- 
2.20.1

